import { expect } from 'chai';
import angularIp21 from '../src/';

describe('ip21SqlService', function () {
    let ip21Sql,
        httpBackend,
        ip21SqlService;

    beforeEach(angular.mock.module(angularIp21));

    beforeEach(angular.mock.inject(function (_ip21SqlService_, $httpBackend) {
        ip21SqlService = _ip21SqlService_;
        httpBackend = $httpBackend;

        ip21Sql = ip21SqlService.create('http://172.21.199.106/ProcessData/AtProcessDataREST.dll/SQL', 10014);
    }));

    it('should return an array of rows of data', function (done) {
        httpBackend.whenPOST('http://172.21.199.106/ProcessData/AtProcessDataREST.dll/SQL').respond({
            data: { 'data': [{ 'r': 'D', 'cols': [{ 'i': 0, 'n': 'name' }, { 'i': 1, 'n': 'IP_DESCRIPTION' }], 'rows': [{ 'fld': [{ 'i': 0, 'v': 'TFA-STATUS_PIMS-03' }, { 'i': 1, 'v': '[PIMS TFA] Nº Tags Scan Off' }] }, { 'fld': [{ 'i': 0, 'v': 'TFA-STATUS_PIMS-02' }, { 'i': 1, 'v': '[PIMS TFA] Nº Tags Coleta' }] }] }] }
        });

        ip21Sql.executeSelect('').then(function (rows) {
            expect(rows).to.equal(
                [
                    {
                        IP_DESCRIPTION: '[PIMS TFA] N&#186; Tags Scan Off',
                        name: 'TFA-STATUS_PIMS-03'
                    },
                    {
                        IP_DESCRIPTION: '[PIMS TFA] N&#186; Tags Coleta',
                        name: 'TFA-STATUS_PIMS-02'
                    }
                ]);
            done();
        });

        httpBackend.flush();
    });

    it('should return a TypeError', () => {
        try {
            ip21SqlService.create();
        }
        catch(err) {
            expect(err.message).to.equal('create expects a valid URL string as first parameter');
        }
        
    });

    // it('should return an array of rows of data 2', function (done) {
    //     httpBackend.whenPOST('http://172.21.199.106/ProcessData/AtProcessDataREST.dll/SQL').respond({
    //         data: {data:[{r:'D',cols:[{i:'0',n:'intID'},{i:'1',n:'strTrainID'},{i:'2',n:'strUserTrainID'},{i:'3',n:'intLine'},{i:'4',n:'str#Direction'},{i:'5',n:'intWCMState'},{i:'6',n:'intTBOGIState'},{i:'7',n:'intWSpecState'},{i:'8',n:'intVideoImageState'},{i:'9',n:'tsPassTime'},{i:'10',n:'int#Axles'},{i:'11',n:'int#Loco'},{i:'12',n:'int#Carr'},{i:'13',n:'int#NoTag'},{i:'14',n:'rInSpeed'},{i:'15',n:'rOutSpeed'}],rows:[{fld:[{i:'0',v:'8105'},{i:'1',v:'158D9E0BD'},{i:'2',v:'EVO  000240'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'4'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'28-MAR-17 04:04:13.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'26'},{i:'14',v:37.0000000000000000},{i:'15',v:27.0000000000000000}]},{fld:[{i:'0',v:'8104'},{i:'1',v:'158D9DA48'},{i:'2',v:'EVO  000242'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'28-MAR-17 03:36:40.0'},{i:'10',v:'1330'},{i:'11',v:'3'},{i:'12',v:'328'},{i:'13',v:'22'},{i:'14',v:61.0000000000000000},{i:'15',v:60.0000000000000000}]},{fld:[{i:'0',v:'8103'},{i:'1',v:'158D9D044'},{i:'2',v:'11703280253'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'28-MAR-17 02:53:56.0'},{i:'10',v:'1344'},{i:'11',v:'3'},{i:'12',v:'331'},{i:'13',v:'7'},{i:'14',v:58.0000000000000000},{i:'15',v:72.0000000000000000}]},{fld:[{i:'0',v:'8102'},{i:'1',v:'158D9CC80'},{i:'2',v:'C36  000369'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'4'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'28-MAR-17 02:37:52.0'},{i:'10',v:'22'},{i:'11',v:'1'},{i:'12',v:'4'},{i:'13',v:'0'},{i:'14',v:68.0000000000000000},{i:'15',v:68.0000000000000000}]},{fld:[{i:'0',v:'8101'},{i:'1',v:'158D9C76D'},{i:'2',v:'EVO  000214'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'28-MAR-17 02:16:13.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'34'},{i:'14',v:57.0000000000000000},{i:'15',v:38.0000000000000000}]},{fld:[{i:'0',v:'8100'},{i:'1',v:'158D9B6BE'},{i:'2',v:'EVO  000254'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'28-MAR-17 01:05:02.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'6'},{i:'14',v:48.0000000000000000},{i:'15',v:54.0000000000000000}]},{fld:[{i:'0',v:'8099'},{i:'1',v:'158D9B1C5'},{i:'2',v:'SD70 008652'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'28-MAR-17 00:43:49.0'},{i:'10',v:'612'},{i:'11',v:'1'},{i:'12',v:'151'},{i:'13',v:'146'},{i:'14',v:60.0000000000000000},{i:'15',v:46.0000000000000000}]},{fld:[{i:'0',v:'8098'},{i:'1',v:'158D9A3E2'},{i:'2',v:'11703272344'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 23:44:34.0'},{i:'10',v:'632'},{i:'11',v:'1'},{i:'12',v:'156'},{i:'13',v:'151'},{i:'14',v:68.0000000000000000},{i:'15',v:54.0000000000000000}]},{fld:[{i:'0',v:'8097'},{i:'1',v:'158D99DF7'},{i:'2',v:'SD80 000102'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 23:19:19.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'21'},{i:'14',v:51.0000000000000000},{i:'15',v:67.0000000000000000}]},{fld:[{i:'0',v:'8096'},{i:'1',v:'158D99955'},{i:'2',v:'EVO  000243'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 22:59:33.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'14'},{i:'14',v:77.0000000000000000},{i:'15',v:78.0000000000000000}]},{fld:[{i:'0',v:'8095'},{i:'1',v:'158D99093'},{i:'2',v:'11703272222'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'4'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 22:22:11.0'},{i:'10',v:'210'},{i:'11',v:'2'},{i:'12',v:'49'},{i:'13',v:'48'},{i:'14',v:67.0000000000000000},{i:'15',v:69.0000000000000000}]},{fld:[{i:'0',v:'8094'},{i:'1',v:'158D98C77'},{i:'2',v:'SD70 008256'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 22:04:39.0'},{i:'10',v:'258'},{i:'11',v:'1'},{i:'12',v:'63'},{i:'13',v:'31'},{i:'14',v:59.0000000000000000},{i:'15',v:57.0000000000000000}]},{fld:[{i:'0',v:'8093'},{i:'1',v:'158D9857B'},{i:'2',v:'11703272134'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 21:34:51.0'},{i:'10',v:'1344'},{i:'11',v:'3'},{i:'12',v:'331'},{i:'13',v:'13'},{i:'14',v:63.0000000000000000},{i:'15',v:70.0000000000000000}]},{fld:[{i:'0',v:'8092'},{i:'1',v:'158D98058'},{i:'2',v:'C44  000803'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 21:12:56.0'},{i:'10',v:'1336'},{i:'11',v:'4'},{i:'12',v:'328'},{i:'13',v:'21'},{i:'14',v:58.0000000000000000},{i:'15',v:42.0000000000000000}]},{fld:[{i:'0',v:'8091'},{i:'1',v:'158D97878'},{i:'2',v:'EVO  000222'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 20:39:20.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'14'},{i:'14',v:70.0000000000000000},{i:'15',v:58.0000000000000000}]},{fld:[{i:'0',v:'8090'},{i:'1',v:'158D97377'},{i:'2',v:'EVO  000233'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 20:17:59.0'},{i:'10',v:'1330'},{i:'11',v:'3'},{i:'12',v:'328'},{i:'13',v:'14'},{i:'14',v:60.0000000000000000},{i:'15',v:43.0000000000000000}]},{fld:[{i:'0',v:'8089'},{i:'1',v:'158D96BF0'},{i:'2',v:'EVO  000238'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 19:45:52.0'},{i:'10',v:'892'},{i:'11',v:'2'},{i:'12',v:'220'},{i:'13',v:'4'},{i:'14',v:54.0000000000000000},{i:'15',v:44.0000000000000000}]},{fld:[{i:'0',v:'8088'},{i:'1',v:'158D965BE'},{i:'2',v:'EVO  000245'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 19:19:26.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'14'},{i:'14',v:66.0000000000000000},{i:'15',v:58.0000000000000000}]},{fld:[{i:'0',v:'8087'},{i:'1',v:'158D96056'},{i:'2',v:'EVO  002002'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 18:56:22.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'8'},{i:'14',v:47.0000000000000000},{i:'15',v:31.0000000000000000}]},{fld:[{i:'0',v:'8086'},{i:'1',v:'158D95AAD'},{i:'2',v:'11703271832'},{i:'3',v:'1'},{i:'4',v:'CKS'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 18:32:13.0'},{i:'10',v:'600'},{i:'11',v:'1'},{i:'12',v:'148'},{i:'13',v:'142'},{i:'14',v:44.0000000000000000},{i:'15',v:66.0000000000000000}]},{fld:[{i:'0',v:'8085'},{i:'1',v:'158D95558'},{i:'2',v:'EVO  002009'},{i:'3',v:'1'},{i:'4',v:'SLZ'},{i:'5',v:'1'},{i:'6',v:'1'},{i:'7',v:'1'},{i:'8',v:'1'},{i:'9',v:'27-MAR-17 18:09:28.0'},{i:'10',v:'1338'},{i:'11',v:'3'},{i:'12',v:'330'},{i:'13',v:'8'},{i:'14',v:59.0000000000000000},{i:'15',v:42.0000000000000000}]}]}]}
    //     });

    //     ip21Sql.executeSelect('').then(function (rows) {
    //         expect(rows).to.equal(
    //             [
    //                 {
    //                     IP_DESCRIPTION: '[PIMS TFA] N&#186; Tags Scan Off',
    //                     name: 'TFA-STATUS_PIMS-03'
    //                 },
    //                 {
    //                     IP_DESCRIPTION: '[PIMS TFA] N&#186; Tags Coleta',
    //                     name: 'TFA-STATUS_PIMS-02'
    //                 }
    //             ]);
    //             done();
    //     });

    //     httpBackend.flush();
    // });
});